@@ -1,17 +1,24 @@
+import requests
 from .exceptions import OnboardApiException, OnboardTemporaryException
+from typing import List, Iterable, TypeVar, Callable
+
+T = TypeVar('T')
 
 
-def divide_chunks(l, n):
-    # looping till length l
-    for i in range(0, len(l), n):
-        yield l[i:i + n]
+def divide_chunks(input_list: List[T], n: int) -> Iterable[List[T]]:
+    # looping till length input_list
+    for i in range(0, len(input_list), n):
+        yield input_list[i:i + n]
 
 
-def json(func):
+def json(func: Callable[..., T]) -> Callable[..., T]:
     """Decorator for making sure requests responses are handled consistently"""
+    # the type annotations on json are a lie to let us type the methods in client
+    # with approximate descriptions of the JSON they return, even though the methods
+    # as implemented return requests.Response objects
     def wrapper(*args, **kwargs):
         try:
-            res = func(*args, **kwargs)
+            res: requests.Response = func(*args, **kwargs)  # type: ignore[assignment]
             if res is None:
                 return None
 
@@ -22,9 +29,9 @@ def json(func):
                 return wrapper(*args, **kwargs)
 
             if res.status_code > 499:
-                raise OnboardTemporaryException(res.text)
+                raise OnboardTemporaryException(res.text or res.status_code)
             if res.status_code > 399:
-                raise OnboardApiException(res.text)
+                raise OnboardApiException(res.text or res.status_code)
 
             if hasattr(wrapper, 'raw_response'):
                 return res
